@@ -1,4 +1,4 @@
-#   Copyright 2024 The PyMC Developers
+#   Copyright 2024 - present The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -13,12 +13,12 @@
 #   limitations under the License.
 
 import io
+import typing
 import urllib.request
-import warnings
 
 from collections.abc import Sequence
 from copy import copy
-from typing import cast
+from typing import Union, cast
 
 import numpy as np
 import pandas as pd
@@ -30,23 +30,19 @@ from pytensor.compile.builders import OpFromGraph
 from pytensor.compile.sharedvalue import SharedVariable
 from pytensor.graph.basic import Variable
 from pytensor.raise_op import Assert
-from pytensor.scalar import Cast
-from pytensor.tensor.elemwise import Elemwise
 from pytensor.tensor.random.basic import IntegersRV
-from pytensor.tensor.type import TensorType
 from pytensor.tensor.variable import TensorConstant, TensorVariable
 
-import pymc as pm
-
-from pymc.pytensorf import GeneratorOp, convert_data, smarttypeX
+from pymc.exceptions import ShapeError
+from pymc.pytensorf import convert_data, rvs_in_graph
 from pymc.vartypes import isgenerator
 
+if typing.TYPE_CHECKING:
+    from pymc.model.core import Model
+
 __all__ = [
-    "ConstantData",
     "Data",
-    "GeneratorAdapter",
     "Minibatch",
-    "MutableData",
     "get_data",
 ]
 BASE_URL = "https://raw.githubusercontent.com/pymc-devs/pymc-examples/main/examples/data/{filename}"
@@ -86,51 +82,6 @@ class GenTensorVariable(TensorVariable):
         return cp
 
 
-class GeneratorAdapter:
-    """Class that helps infer data type of generator.
-
-    It looks at the first item, preserving the order of the resulting generator.
-    """
-
-    def make_variable(self, gop, name=None):
-        var = GenTensorVariable(gop, self.tensortype, name)
-        var.tag.test_value = self.test_value
-        return var
-
-    def __init__(self, generator):
-        if not pm.vartypes.isgenerator(generator):
-            raise TypeError("Object should be generator like")
-        self.test_value = smarttypeX(copy(next(generator)))
-        # make pickling potentially possible
-        self._yielded_test_value = False
-        self.gen = generator
-        self.tensortype = TensorType(self.test_value.dtype, ((False,) * self.test_value.ndim))
-
-    # python3 generator
-    def __next__(self):
-        """Next value in the generator."""
-        if not self._yielded_test_value:
-            self._yielded_test_value = True
-            return self.test_value
-        else:
-            return smarttypeX(copy(next(self.gen)))
-
-    # python2 generator
-    next = __next__
-
-    def __iter__(self):
-        """Return an iterator."""
-        return self
-
-    def __eq__(self, other):
-        """Return true if both objects are actually the same."""
-        return id(self) == id(other)
-
-    def __hash__(self):
-        """Return a hash of the object."""
-        return hash(id(self))
-
-
 class MinibatchIndexRV(IntegersRV):
     _print_name = ("minibatch_index", r"\operatorname{minibatch\_index}")
 
@@ -158,20 +109,12 @@ def is_valid_observed(v) -> bool:
         return True
 
     return (
-        # The only PyTensor operation we allow on observed data is type casting
-        # Although we could allow for any graph that does not depend on other RVs
-        (
-            isinstance(v.owner.op, Elemwise)
-            and isinstance(v.owner.op.scalar_op, Cast)
-            and is_valid_observed(v.owner.inputs[0])
-        )
+        not rvs_in_graph(v)
         # Or Minibatch
         or (
             isinstance(v.owner.op, MinibatchOp)
             and all(is_valid_observed(inp) for inp in v.owner.inputs)
         )
-        # Or Generator
-        or isinstance(v.owner.op, GeneratorOp)
     )
 
 
@@ -197,7 +140,7 @@ def Minibatch(variable: TensorVariable, *variables: TensorVariable, batch_size:
     for i, v in enumerate(tensors):
         if not is_valid_observed(v):
             raise ValueError(
-                f"{i}: {v} is not valid for Minibatch, only constants or constants.astype(dtype) are allowed"
+                f"{i}: {v} is not valid for Minibatch, only non-random variables are allowed"
             )
 
     upper = tensors[0].shape[0]
@@ -256,8 +199,8 @@ def determine_coords(
 
     if isinstance(value, np.ndarray) and dims is not None:
         if len(dims) != value.ndim:
-            raise pm.exceptions.ShapeError(
-                "Invalid data shape. The rank of the dataset must match the " "length of `dims`.",
+            raise ShapeError(
+                "Invalid data shape. The rank of the dataset must match the length of `dims`.",
                 actual=value.shape,
                 expected=value.ndim,
             )
@@ -274,66 +217,6 @@ def determine_coords(
     return coords, new_dims
 
 
-def ConstantData(
-    name: str,
-    value,
-    *,
-    dims: Sequence[str] | None = None,
-    coords: dict[str, Sequence | np.ndarray] | None = None,
-    infer_dims_and_coords=False,
-    **kwargs,
-) -> TensorConstant:
-    """Alias for ``pm.Data``.
-
-    Registers the ``value`` as a :class:`~pytensor.tensor.TensorConstant` with the model.
-    For more information, please reference :class:`pymc.Data`.
-    """
-    warnings.warn(
-        "ConstantData is deprecated. All Data variables are now mutable. Use Data instead.",
-        FutureWarning,
-    )
-
-    var = Data(
-        name,
-        value,
-        dims=dims,
-        coords=coords,
-        infer_dims_and_coords=infer_dims_and_coords,
-        **kwargs,
-    )
-    return cast(TensorConstant, var)
-
-
-def MutableData(
-    name: str,
-    value,
-    *,
-    dims: Sequence[str] | None = None,
-    coords: dict[str, Sequence | np.ndarray] | None = None,
-    infer_dims_and_coords=False,
-    **kwargs,
-) -> SharedVariable:
-    """Alias for ``pm.Data``.
-
-    Registers the ``value`` as a :class:`~pytensor.compile.sharedvalue.SharedVariable`
-    with the model. For more information, please reference :class:`pymc.Data`.
-    """
-    warnings.warn(
-        "MutableData is deprecated. All Data variables are now mutable. Use Data instead.",
-        FutureWarning,
-    )
-
-    var = Data(
-        name,
-        value,
-        dims=dims,
-        coords=coords,
-        infer_dims_and_coords=infer_dims_and_coords,
-        **kwargs,
-    )
-    return cast(SharedVariable, var)
-
-
 def Data(
     name: str,
     value,
@@ -341,7 +224,7 @@ def Data(
     dims: Sequence[str] | None = None,
     coords: dict[str, Sequence | np.ndarray] | None = None,
     infer_dims_and_coords=False,
-    mutable: bool | None = None,
+    model: Union["Model", None] = None,
     **kwargs,
 ) -> SharedVariable | TensorConstant:
     """Create a data container that registers a data variable with the model.
@@ -406,6 +289,8 @@ def Data(
     ...         model.set_data("data", data_vals)
     ...         idatas.append(pm.sample())
     """
+    from pymc.model.core import modelcontext
+
     if coords is None:
         coords = {}
 
@@ -413,8 +298,9 @@ def Data(
         value = np.array(value)
 
     # Add data container to the named variables of the model.
-    model = pm.Model.get_context(error_if_none=False)
-    if model is None:
+    try:
+        model = modelcontext(model)
+    except TypeError:
         raise TypeError(
             "No model on context stack, which is needed to instantiate a data container. "
             "Add variable inside a 'with model:' block."
@@ -436,17 +322,12 @@ def Data(
             "Pass them directly to `observed` if you want to trigger auto-imputation"
         )
 
-    if mutable is not None:
-        warnings.warn(
-            "Data is now always mutable. Specifying the `mutable` kwarg will raise an error in a future release",
-            FutureWarning,
-        )
     x = pytensor.shared(arr, name, **kwargs)
 
     if isinstance(dims, str):
         dims = (dims,)
     if not (dims is None or len(dims) == x.ndim):
-        raise pm.exceptions.ShapeError(
+        raise ShapeError(
             "Length of `dims` must match the dimensions of the dataset.",
             actual=len(dims),
             expected=x.ndim,
