@@ -71,7 +71,7 @@ from pymc.pytensorf import normalize_rng_param
 
 class Binomial(Discrete):
     R"""
-    Binomial log-likelihood.
+    Binomial distribution.
 
     The discrete probability distribution of the number of successes
     in a sequence of n independent yes/no experiments, each of which
@@ -176,7 +176,7 @@ class Binomial(Discrete):
 
 class BetaBinomial(Discrete):
     R"""
-    Beta-binomial log-likelihood.
+    Beta-binomial distribution.
 
     Equivalent to binomial random variable with success probability
     drawn from a beta distribution.
@@ -293,7 +293,7 @@ class BetaBinomial(Discrete):
 
 
 class Bernoulli(Discrete):
-    R"""Bernoulli log-likelihood.
+    R"""Bernoulli distribution.
 
     The Bernoulli distribution describes the probability of successes
     (x=1) and failures (x=0).
@@ -413,7 +413,7 @@ class DiscreteWeibullRV(SymbolicRandomVariable):
 
 
 class DiscreteWeibull(Discrete):
-    R"""Discrete Weibull log-likelihood.
+    R"""Discrete Weibull distribution.
 
     The discrete Weibull distribution is a flexible model of count data that
     can handle both over- and under-dispersion.
@@ -506,7 +506,7 @@ class DiscreteWeibull(Discrete):
 
 class Poisson(Discrete):
     R"""
-    Poisson log-likelihood.
+    Poisson distribution.
 
     Often used to model the number of events occurring in a fixed period
     of time when the times at which events occur are independent.
@@ -602,7 +602,7 @@ class Poisson(Discrete):
 
 class NegativeBinomial(Discrete):
     R"""
-    Negative binomial log-likelihood.
+    Negative binomial distribution.
 
     The negative binomial distribution describes a Poisson random variable
     whose rate parameter is gamma distributed.
@@ -750,7 +750,7 @@ class NegativeBinomial(Discrete):
 
 class Geometric(Discrete):
     R"""
-    Geometric log-likelihood.
+    Geometric distribution.
 
     The probability that the first success in a sequence of Bernoulli
     trials occurs on the x'th trial.
@@ -1084,7 +1084,7 @@ class DiscreteUniform(Discrete):
 
 class Categorical(Discrete):
     R"""
-    Categorical log-likelihood.
+    Categorical distribution.
 
     The most general discrete distribution. The pmf of this distribution is
 
@@ -1155,29 +1155,58 @@ class Categorical(Discrete):
             mode = pt.full(size, mode)
         return mode
 
-    def logp(value, p):
-        k = pt.shape(p)[-1]
-        value_clip = pt.clip(value, 0, k - 1)
+    @staticmethod
+    def _safe_index_value_p(value, p):
+        # Find the probabily of the given value by indexing in p,
+        # after handling broadcasting and invalid values.
 
         # In the standard case p has one more dimension than value
         dim_diff = p.type.ndim - value.type.ndim
         if dim_diff > 1:
             # p brodacasts implicitly beyond value
-            value_clip = pt.shape_padleft(value_clip, dim_diff - 1)
+            value = pt.shape_padleft(value, dim_diff - 1)
         elif dim_diff < 1:
             # value broadcasts implicitly beyond p
             p = pt.shape_padleft(p, 1 - dim_diff)
 
-        a = pt.log(pt.take_along_axis(p, value_clip[..., None], axis=-1).squeeze(-1))
+        k = pt.shape(p)[-1]
+        value_clip = pt.clip(value, 0, k - 1).astype(int)
+        return value, pt.log(pt.take_along_axis(p, value_clip[..., None], axis=-1).squeeze(-1))
 
-        res = pt.switch(
+    def logp(value, p):
+        k = pt.shape(p)[-1]
+        value, safe_value_p = Categorical._safe_index_value_p(value, p)
+
+        value_p = pt.switch(
             pt.or_(pt.lt(value, 0), pt.gt(value, k - 1)),
             -np.inf,
-            a,
+            safe_value_p,
         )
 
         return check_parameters(
-            res,
+            value_p,
+            0 <= p,
+            p <= 1,
+            pt.isclose(pt.sum(p, axis=-1), 1),
+            msg="0 <= p <=1, sum(p) = 1",
+        )
+
+    def logcdf(value, p):
+        k = pt.shape(p)[-1]
+        value, safe_value_p = Categorical._safe_index_value_p(value, p.cumsum(-1))
+
+        value_p = pt.switch(
+            pt.lt(value, 0),
+            -np.inf,
+            pt.switch(
+                pt.gt(value, k - 1),
+                0,
+                safe_value_p,
+            ),
+        )
+
+        return check_parameters(
+            value_p,
             0 <= p,
             p <= 1,
             pt.isclose(pt.sum(p, axis=-1), 1),
@@ -1328,7 +1357,7 @@ class OrderedProbit:
 
     Examples
     --------
-    .. code:: python
+    .. code-block:: python
 
         # Generate data for a simple 1 dimensional example problem
         n1_c = 300; n2_c = 300; n3_c = 300
