@@ -11,17 +11,13 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
-import warnings
 
 from functools import singledispatch
 
 import numpy as np
 import pytensor.tensor as pt
 
-
-# ignore mypy error because it somehow considers that
-# "numpy.core.numeric has no attribute normalize_axis_tuple"
-from numpy.core.numeric import normalize_axis_tuple  # type: ignore[attr-defined]
+from numpy.lib.array_utils import normalize_axis_tuple
 from pytensor.graph import Op
 from pytensor.tensor import TensorVariable
 
@@ -51,22 +47,6 @@ __all__ = [
 ]
 
 
-def __getattr__(name):
-    if name in ("univariate_ordered", "multivariate_ordered"):
-        warnings.warn(f"{name} has been deprecated, use ordered instead.", FutureWarning)
-        return ordered
-
-    if name in ("univariate_sum_to_1", "multivariate_sum_to_1"):
-        warnings.warn(f"{name} has been deprecated, use sum_to_1 instead.", FutureWarning)
-        return sum_to_1
-
-    if name == "RVTransform":
-        warnings.warn("RVTransform has been renamed to Transform", FutureWarning)
-        return Transform
-
-    raise AttributeError(f"module {__name__} has no attribute {name}")
-
-
 @singledispatch
 def _default_transform(op: Op, rv: TensorVariable):
     """Return default transform for a given Distribution `Op`."""
@@ -92,26 +72,46 @@ class LogExpM1(Transform):
 
 
 class Ordered(Transform):
+    """
+    Transforms a vector of values into a vector of ordered values.
+
+    Parameters
+    ----------
+    positive: If True, all values are positive. This has better geometry than just chaining with a log transform.
+    ascending: If True, the values are in ascending order (default). If False, the values are in descending order.
+    """
+
     name = "ordered"
 
-    def __init__(self, ndim_supp=None):
-        if ndim_supp is not None:
-            warnings.warn("ndim_supp argument is deprecated and has no effect", FutureWarning)
+    def __init__(self, positive=False, ascending=True):
+        self.positive = positive
+        self.ascending = ascending
 
     def backward(self, value, *inputs):
-        x = pt.zeros(value.shape)
-        x = pt.set_subtensor(x[..., 0], value[..., 0])
-        x = pt.set_subtensor(x[..., 1:], pt.exp(value[..., 1:]))
-        return pt.cumsum(x, axis=-1)
+        if self.positive:  # Transform both initial value and deltas to be positive
+            x = pt.exp(value)
+        else:  # Transform only deltas to be positive
+            x = pt.empty(value.shape)
+            x = pt.set_subtensor(x[..., 0], value[..., 0])
+            x = pt.set_subtensor(x[..., 1:], pt.exp(value[..., 1:]))
+        x = pt.cumsum(x, axis=-1)  # Add deltas cumulatively to initial value
+        if not self.ascending:
+            x = x[..., ::-1]
+        return x
 
     def forward(self, value, *inputs):
-        y = pt.zeros(value.shape)
-        y = pt.set_subtensor(y[..., 0], value[..., 0])
+        if not self.ascending:
+            value = value[..., ::-1]
+        y = pt.empty(value.shape)
+        y = pt.set_subtensor(y[..., 0], pt.log(value[..., 0]) if self.positive else value[..., 0])
         y = pt.set_subtensor(y[..., 1:], pt.log(value[..., 1:] - value[..., :-1]))
         return y
 
     def log_jac_det(self, value, *inputs):
-        return pt.sum(value[..., 1:], axis=-1)
+        if self.positive:
+            return pt.sum(value, axis=-1)
+        else:
+            return pt.sum(value[..., 1:], axis=-1)
 
 
 class SumTo1(Transform):
@@ -123,10 +123,6 @@ class SumTo1(Transform):
 
     name = "sumto1"
 
-    def __init__(self, ndim_supp=None):
-        if ndim_supp is not None:
-            warnings.warn("ndim_supp argument is deprecated and has no effect", FutureWarning)
-
     def backward(self, value, *inputs):
         remaining = 1 - pt.sum(value[..., :], axis=-1, keepdims=True)
         return pt.concatenate([value[..., :], remaining], axis=-1)
