@@ -1,4 +1,4 @@
-#   Copyright 2024 The PyMC Developers
+#   Copyright 2024 - present The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -39,25 +39,6 @@ solve_upper = partial(solve_triangular, lower=False)
 __all__ = ["TP", "Latent", "LatentKron", "Marginal", "MarginalApprox", "MarginalKron"]
 
 
-_noise_deprecation_warning = (
-    "The 'noise' parameter has been been changed to 'sigma' "
-    "in order to standardize the GP API and will be "
-    "deprecated in future releases."
-)
-
-
-def _handle_sigma_noise_parameters(sigma, noise):
-    """Help transition of 'noise' parameter to be named 'sigma'."""
-    if (sigma is None and noise is None) or (sigma is not None and noise is not None):
-        raise ValueError("'sigma' argument must be specified.")
-
-    if sigma is None:
-        warnings.warn(_noise_deprecation_warning, FutureWarning)
-        return noise
-
-    return sigma
-
-
 class Base:
     """Base class."""
 
@@ -117,7 +98,7 @@ class Latent(Base):
 
     Examples
     --------
-    .. code:: python
+    .. code-block:: python
 
         # A one dimensional column vector of inputs.
         X = np.linspace(0, 1, 10)[:, None]
@@ -281,6 +262,7 @@ class Latent(Base):
         """
         givens = self._get_given_vals(given)
         mu, cov = self._build_conditional(Xnew, *givens, jitter)
+        kwargs.setdefault("method", "svd")
         f = pm.MvNormal(name, mu=mu, cov=cov, **kwargs)
 
         return f
@@ -438,7 +420,7 @@ class Marginal(Base):
 
     Examples
     --------
-    .. code:: python
+    .. code-block:: python
 
         # A one dimensional column vector of inputs.
         X = np.linspace(0, 1, 10)[:, None]
@@ -476,8 +458,7 @@ class Marginal(Base):
         name,
         X,
         y,
-        sigma=None,
-        noise=None,
+        sigma,
         jitter=JITTER_DEFAULT,
         is_observed=True,
         **kwargs,
@@ -504,8 +485,6 @@ class Marginal(Base):
         sigma : float, Variable, or Covariance, default ~pymc.gp.cov.WhiteNoise
             Standard deviation of the Gaussian noise.  Can also be a Covariance for
             non-white noise.
-        noise : float, Variable, or Covariance, optional
-            Deprecated. Previous parameterization of `sigma`.
         jitter : float, default 1e-6
             A small correction added to the diagonal of positive semi-definite
             covariance matrices to ensure numerical stability.
@@ -515,8 +494,6 @@ class Marginal(Base):
             Extra keyword arguments that are passed to :class:`~pymc.MvNormal` distribution
             constructor.
         """
-        sigma = _handle_sigma_noise_parameters(sigma=sigma, noise=noise)
-
         noise_func = sigma if isinstance(sigma, BaseCovariance) else pm.gp.cov.WhiteNoise(sigma)
         mu, cov = self._build_marginal_likelihood(X=X, noise_func=noise_func, jitter=jitter)
         self.X = X
@@ -543,10 +520,6 @@ class Marginal(Base):
             cov_total = self.cov_func
             mean_total = self.mean_func
 
-        if "noise" in given:
-            warnings.warn(_noise_deprecation_warning, FutureWarning)
-            given["sigma"] = given["noise"]
-
         if all(val in given for val in ["X", "y", "sigma"]):
             X, y, sigma = given["X"], given["y"], given["sigma"]
             noise_func = sigma if isinstance(sigma, BaseCovariance) else pm.gp.cov.WhiteNoise(sigma)
@@ -718,7 +691,7 @@ class MarginalApprox(Marginal):
 
     Examples
     --------
-    .. code:: python
+    .. code-block:: python
 
         # A one dimensional column vector of inputs.
         X = np.linspace(0, 1, 10)[:, None]
@@ -803,9 +776,7 @@ class MarginalApprox(Marginal):
         quadratic = 0.5 * (pt.dot(r, r_l) - pt.dot(c, c))
         return -1.0 * (constant + logdet + quadratic + trace)
 
-    def marginal_likelihood(
-        self, name, X, Xu, y, sigma=None, noise=None, jitter=JITTER_DEFAULT, **kwargs
-    ):
+    def marginal_likelihood(self, name, X, Xu, y, sigma, jitter=JITTER_DEFAULT, **kwargs):
         R"""
         Return the approximate marginal likelihood distribution.
 
@@ -826,8 +797,6 @@ class MarginalApprox(Marginal):
             noise.  Must have shape `(n, )`.
         sigma : float, Variable
             Standard deviation of the Gaussian noise.
-        noise : float, Variable, optional
-            Previous parameterization of `sigma`.
         jitter : float, default 1e-6
             A small correction added to the diagonal of positive semi-definite
             covariance matrices to ensure numerical stability.
@@ -839,7 +808,7 @@ class MarginalApprox(Marginal):
         self.Xu = Xu
         self.y = y
 
-        self.sigma = _handle_sigma_noise_parameters(sigma=sigma, noise=noise)
+        self.sigma = sigma
 
         approx_loglik = self._build_marginal_likelihood_loglik(
             y=self.y, X=self.X, Xu=self.Xu, sigma=self.sigma, jitter=jitter
@@ -962,7 +931,7 @@ class LatentKron(Base):
 
     Examples
     --------
-    .. code:: python
+    .. code-block:: python
 
         # One dimensional column vectors of inputs
         X1 = np.linspace(0, 1, 10)[:, None]
@@ -1065,7 +1034,7 @@ class LatentKron(Base):
         1, and 4, respectively, then `Xnew` must have 7 columns and a
         covariance between the prediction points
 
-        .. code:: python
+        .. code-block:: python
 
             cov_func(Xnew) = cov_func1(Xnew[:, :2]) * cov_func1(Xnew[:, 2:3]) * cov_func1(Xnew[:, 3:])
 
@@ -1117,13 +1086,13 @@ class MarginalKron(Base):
 
     Examples
     --------
-    .. code:: python
+    .. code-block:: python
 
         # One dimensional column vectors of inputs
         X1 = np.linspace(0, 1, 10)[:, None]
         X2 = np.linspace(0, 2, 5)[:, None]
         Xs = [X1, X2]
-        y = np.random.randn(len(X1)*len(X2))  # toy data
+        y = np.random.randn(len(X1) * len(X2))  # toy data
         with pm.Model() as model:
             # Specify the covariance functions for each Xi
             cov_func1 = pm.gp.cov.ExpQuad(1, ls=0.1)  # Must accept X1 without error
@@ -1265,7 +1234,7 @@ class MarginalKron(Base):
         1, and 4, respectively, then `Xnew` must have 7 columns and a
         covariance between the prediction points
 
-        .. code:: python
+        .. code-block:: python
 
             cov_func(Xnew) = cov_func1(Xnew[:, :2]) * cov_func1(Xnew[:, 2:3]) * cov_func1(Xnew[:, 3:])
 
