@@ -16,11 +16,12 @@ import warnings
 from collections.abc import Mapping, Sequence
 from typing import Any, Union
 
-from pytensor.graph import ancestors
+import pytensor
+
+from pytensor.graph import Constant, ancestors
 from pytensor.tensor import TensorVariable
 
 from pymc.logprob.transforms import Transform
-from pymc.logprob.utils import rvs_in_graph
 from pymc.model.core import Model
 from pymc.model.fgraph import (
     ModelDeterministic,
@@ -39,7 +40,7 @@ from pymc.model.transform.basic import (
     parse_vars,
     prune_vars_detached_from_observed,
 )
-from pymc.pytensorf import replace_vars_in_graphs, toposort_replace
+from pymc.pytensorf import replace_vars_in_graphs, rvs_in_graph, toposort_replace
 from pymc.util import get_transformed_name, get_untransformed_name
 
 
@@ -126,7 +127,9 @@ def observe(
 def do(
     model: Model,
     vars_to_interventions: Mapping[Union["str", TensorVariable], Any],
-    prune_vars=False,
+    *,
+    make_interventions_shared: bool = True,
+    prune_vars: bool = False,
 ) -> Model:
     """Replace model variables by intervention variables.
 
@@ -140,6 +143,8 @@ def do(
         Dictionary that maps model variables (or names) to intervention expressions.
         Intervention expressions must have a shape and data type that is compatible
         with the original model variable.
+    make_interventions_shared: bool, defaults to True,
+        Whether to make constant interventions shared variables.
     prune_vars: bool, defaults to False
         Whether to prune model variables that are not connected to any observed variables,
         after the interventions.
@@ -170,11 +175,14 @@ def do(
 
     """
     do_mapping = {}
-    for var, obs in vars_to_interventions.items():
+    for var, intervention in vars_to_interventions.items():
         if isinstance(var, str):
             var = model[var]
         try:
-            do_mapping[var] = var.type.filter_variable(obs)
+            intervention = var.type.filter_variable(intervention)
+            if make_interventions_shared and isinstance(intervention, Constant):
+                intervention = pytensor.shared(intervention.data, name=var.name)
+            do_mapping[var] = intervention
         except TypeError as err:
             raise TypeError(
                 "Incompatible replacement type. Make sure the shape and datatype of the interventions match the original variables"
@@ -350,7 +358,7 @@ def remove_value_transforms(
     """
     if vars is None:
         vars = model.free_RVs
-    return change_value_transforms(model, {var: None for var in vars})
+    return change_value_transforms(model, dict.fromkeys(vars))
 
 
 __all__ = (
