@@ -20,24 +20,26 @@ import warnings
 from collections.abc import Callable, Iterable, Sequence
 from typing import (
     Any,
+    Literal,
     TypeAlias,
     cast,
+    overload,
 )
 
 import numpy as np
 import xarray
+import xarray as xr
 
 from arviz import InferenceData
 from pytensor import tensor as pt
+from pytensor.graph import vectorize_graph
 from pytensor.graph.basic import (
     Apply,
     Constant,
     Variable,
-    ancestors,
-    general_toposort,
-    walk,
 )
 from pytensor.graph.fg import FunctionGraph
+from pytensor.graph.traversal import ancestors, general_toposort, walk
 from pytensor.tensor.random.var import RandomGeneratorSharedVariable
 from pytensor.tensor.sharedvar import SharedVariable, TensorSharedVariable
 from pytensor.tensor.variable import TensorConstant
@@ -50,13 +52,13 @@ import pymc as pm
 from pymc.backends.arviz import _DefaultTrace, dataset_to_point_list
 from pymc.backends.base import MultiTrace
 from pymc.blocking import PointType
+from pymc.distributions.shape_utils import change_dist_size
 from pymc.model import Model, modelcontext
-from pymc.pytensorf import compile
+from pymc.progress_bar import CustomProgress, default_progress_theme
+from pymc.pytensorf import compile, rvs_in_graph
 from pymc.util import (
-    CustomProgress,
     RandomState,
     _get_seeds_per_chain,
-    default_progress_theme,
     get_default_varnames,
     point_wrapper,
 )
@@ -66,6 +68,7 @@ __all__ = (
     "draw",
     "sample_posterior_predictive",
     "sample_prior_predictive",
+    "vectorize_over_posterior",
 )
 
 ArrayLike: TypeAlias = np.ndarray | list[float]
@@ -360,6 +363,28 @@ def observed_dependent_deterministics(model: Model, extra_observeds=None):
     ]
 
 
+@overload
+def sample_prior_predictive(
+    draws: int = 500,
+    model: Model | None = None,
+    var_names: Iterable[str] | None = None,
+    random_seed: RandomState = None,
+    return_inferencedata: Literal[True] = True,
+    idata_kwargs: dict | None = None,
+    compile_kwargs: dict | None = None,
+    samples: int | None = None,
+) -> InferenceData: ...
+@overload
+def sample_prior_predictive(
+    draws: int = 500,
+    model: Model | None = None,
+    var_names: Iterable[str] | None = None,
+    random_seed: RandomState = None,
+    return_inferencedata: Literal[False] = False,
+    idata_kwargs: dict | None = None,
+    compile_kwargs: dict | None = None,
+    samples: int | None = None,
+) -> dict[str, np.ndarray]: ...
 def sample_prior_predictive(
     draws: int = 500,
     model: Model | None = None,
@@ -469,6 +494,36 @@ def sample_prior_predictive(
     return pm.to_inference_data(prior=prior, **ikwargs)
 
 
+@overload
+def sample_posterior_predictive(
+    trace,
+    model: Model | None = None,
+    var_names: list[str] | None = None,
+    sample_dims: list[str] | None = None,
+    random_seed: RandomState = None,
+    progressbar: bool = True,
+    progressbar_theme: Theme | None = default_progress_theme,
+    return_inferencedata: Literal[True] = True,
+    extend_inferencedata: bool = False,
+    predictions: bool = False,
+    idata_kwargs: dict | None = None,
+    compile_kwargs: dict | None = None,
+) -> InferenceData: ...
+@overload
+def sample_posterior_predictive(
+    trace,
+    model: Model | None = None,
+    var_names: list[str] | None = None,
+    sample_dims: list[str] | None = None,
+    random_seed: RandomState = None,
+    progressbar: bool = True,
+    progressbar_theme: Theme | None = default_progress_theme,
+    return_inferencedata: Literal[False] = False,
+    extend_inferencedata: bool = False,
+    predictions: bool = False,
+    idata_kwargs: dict | None = None,
+    compile_kwargs: dict | None = None,
+) -> dict[str, np.ndarray]: ...
 def sample_posterior_predictive(
     trace,
     model: Model | None = None,
@@ -546,7 +601,7 @@ def sample_posterior_predictive(
     The most common use of `sample_posterior_predictive` is to perform posterior predictive checks (in-sample predictions)
     and new model predictions (out-of-sample predictions).
 
-    .. code:: python
+    .. code-block:: python
 
         import pymc as pm
 
@@ -575,7 +630,7 @@ def sample_posterior_predictive(
     For the last example we could have created a new predictions model. Note that we have to specify
     `var_names` explicitly, because the newly defined `y` was not given any observations:
 
-    .. code:: python
+    .. code-block:: python
 
         with pm.Model(coords_mutable={"trial": [3, 4]}) as predictions_model:
             x = pm.MutableData("x", [-2, 2], dims=["trial"])
@@ -583,14 +638,16 @@ def sample_posterior_predictive(
             noise = pm.HalfNormal("noise")
             y = pm.Normal("y", mu=x * beta, sigma=noise, dims=["trial"])
 
-            predictions = pm.sample_posterior_predictive(idata, var_names=["y"], predictions=True).predictions
+            predictions = pm.sample_posterior_predictive(
+                idata, var_names=["y"], predictions=True
+            ).predictions
 
 
     The new model may even have a different structure and unobserved variables that don't exist in the trace.
     These variables will also be forward sampled. In the following example we added a new ``extra_noise``
     variable between the inferred posterior ``noise`` and the new StudentT observational distribution  ``y``:
 
-    .. code:: python
+    .. code-block:: python
 
         with pm.Model(coords_mutable={"trial": [3, 4]}) as distinct_predictions_model:
             x = pm.MutableData("x", [-2, 2], dims=["trial"])
@@ -599,7 +656,9 @@ def sample_posterior_predictive(
             extra_noise = pm.HalfNormal("extra_noise", sigma=noise)
             y = pm.StudentT("y", nu=4, mu=x * beta, sigma=extra_noise, dims=["trial"])
 
-            predictions = pm.sample_posterior_predictive(idata, var_names=["y"], predictions=True).predictions
+            predictions = pm.sample_posterior_predictive(
+                idata, var_names=["y"], predictions=True
+            ).predictions
 
 
     For more about out-of-model predictions, see this `blog post <https://www.pymc-labs.com/blog-posts/out-of-model-predictions-with-pymc/>`_.
@@ -625,7 +684,7 @@ def sample_posterior_predictive(
 
     The following code block explores how the behavior changes with different `var_names`:
 
-    .. code:: python
+    .. code-block:: python
 
         from logging import getLogger
         import pymc as pm
@@ -648,7 +707,7 @@ def sample_posterior_predictive(
     Default behavior. Generate samples of ``obs``, conditioned on the posterior samples of ``z`` found in the trace.
     These are often referred to as posterior predictive samples in the literature:
 
-    .. code:: python
+    .. code-block:: python
 
         with model:
             pm.sample_posterior_predictive(idata, var_names=["obs"], **kwargs)
@@ -725,7 +784,7 @@ def sample_posterior_predictive(
 
     You can manipulate the InferenceData to control the number of samples
 
-    .. code:: python
+    .. code-block:: python
 
         import pymc as pm
 
@@ -735,7 +794,7 @@ def sample_posterior_predictive(
 
     Generate 1 posterior predictive sample for every 5 posterior samples.
 
-    .. code:: python
+    .. code-block:: python
 
         thinned_idata = idata.sel(draw=slice(None, None, 5))
         with model:
@@ -744,7 +803,7 @@ def sample_posterior_predictive(
 
     Generate 5 posterior predictive samples for every posterior sample.
 
-    .. code:: python
+    .. code-block:: python
 
         expanded_idata = idata.copy()
         expanded_idata.posterior = idata.posterior.expand_dims(pred_id=5)
@@ -930,3 +989,97 @@ def sample_posterior_predictive(
         idata.extend(idata_pp)
         return idata
     return idata_pp
+
+
+def vectorize_over_posterior(
+    outputs: list[Variable],
+    posterior: xr.Dataset,
+    input_rvs: list[Variable],
+    allow_rvs_in_graph: bool = True,
+    sample_dims: tuple[str, ...] = ("chain", "draw"),
+) -> list[Variable]:
+    """Vectorize outputs over posterior samples of subset of input rvs.
+
+    This function creates a new graph for the supplied outputs, where the required
+    subset of input rvs are replaced by their posterior samples (chain and draw
+    dimensions are flattened). The other input tensors are kept as is.
+
+    Parameters
+    ----------
+    outputs : list[Variable]
+        The list of variables to vectorize over the posterior samples.
+    posterior : xr.Dataset
+        The posterior samples to use as replacements for the `input_rvs`.
+    input_rvs : list[Variable]
+        The list of random variables to replace with their posterior samples.
+    allow_rvs_in_graph : bool
+        Whether to allow random variables to be present in the graph. If False,
+        an error will be raised if any random variables are found in the graph. If
+        True, the remaining random variables will be resized to match the number of
+        draws from the posterior.
+    sample_dims : tuple[str, ...]
+        The dimensions of the posterior samples to use for vectorizing the `input_rvs`.
+
+
+    Returns
+    -------
+    vectorized_outputs : list[Variable]
+        The vectorized variables
+
+    Raises
+    ------
+    RuntimeError
+        If random variables are found in the graph and `allow_rvs_in_graph` is False
+    """
+    # Identify which free RVs are needed to compute `outputs`
+    needed_rvs: list[Variable] = [
+        rv for rv in ancestors(outputs, blockers=input_rvs) if rv in set(input_rvs)
+    ]
+
+    # Replace needed_rvs with actual posterior samples
+    batch_shape = tuple([len(posterior.coords[dim]) for dim in sample_dims])
+    replace_dict: dict[Variable, Variable] = {}
+    for rv in needed_rvs:
+        posterior_samples = posterior[rv.name].data
+
+        replace_dict[rv] = pt.constant(posterior_samples.astype(rv.dtype), name=rv.name)  # type: ignore[attr-defined]
+
+    # Replace the rvs that remain in the graph with resized versions
+    all_rvs = rvs_in_graph(outputs)
+
+    # Once we give values for the needed_rvs (setting them to their posterior samples),
+    # we need to identify the rvs that only depend on these conditioned values, and
+    # don't depend on any other rvs or output nodes.
+    # These variables need to be resized because they won't be resized implicitly by
+    # the replacement of the needed_rvs or other random variables in the graph when we
+    # later call vectorize_graph.
+    independent_rvs: list[Variable] = []
+    for rv in [
+        rv
+        for rv in general_toposort(  # type: ignore[call-overload]
+            all_rvs, lambda x: x.owner.inputs if x.owner is not None else None
+        )
+        if rv in all_rvs
+    ]:
+        rv_ancestors = ancestors([rv], blockers=[*needed_rvs, *independent_rvs, *outputs])
+        if (
+            rv not in needed_rvs
+            and not ({*outputs, *independent_rvs} & set(rv_ancestors))
+            and {var for var in rv_ancestors if var in all_rvs} <= {rv, *needed_rvs}
+        ):
+            independent_rvs.append(rv)
+    for rv in independent_rvs:
+        replace_dict[rv] = change_dist_size(rv, new_size=batch_shape, expand=True)
+
+    # Vectorize across samples
+    vectorized_outputs = list(vectorize_graph(outputs, replace=replace_dict))
+    for vectorized_output, output in zip(vectorized_outputs, outputs):
+        vectorized_output.name = output.name
+
+    if not allow_rvs_in_graph:
+        remaining_rvs = rvs_in_graph(vectorized_outputs)
+        if remaining_rvs:
+            raise RuntimeError(
+                f"The following random variables found in the extracted graph: {remaining_rvs}"
+            )
+    return vectorized_outputs
